﻿using System.Collections.Generic;
using System.Linq;

namespace MvcPaging.Models
{

    public class PagedList<T> : List<T>
    {

        public PagedList(IQueryable<T> source, int index, int pageSize)
        {

            PagerInfo = new PagerInfo();

            PagerInfo.TotalCount = source.Count();
            PagerInfo.PageSize = pageSize;
            PagerInfo.PageIndex = index;

            PagerInfo.TotalPages = PagerInfo.TotalCount / pageSize;

            if (PagerInfo.TotalCount % pageSize > 0)
                PagerInfo.TotalPages++;

            AddRange(source.Skip((index - 1) * pageSize).Take(pageSize).ToList());

        }

        public PagerInfo PagerInfo { get; private set; }

    }

    public class PagerInfo
    {
        public int TotalPages { get; set; }
        public int TotalCount { get; set; }
        public int PageIndex { get; set; }
        public int PageSize { get; set; }
        public bool HasPreviousPage { get { return (PageIndex > 1); } }
        public bool HasNextPage { get { return (PageIndex * PageSize) <= TotalCount; } }
    }

}